checkRequire("Lua_CommonChatPanel");
Lua_PeakDuelGuessPanel = class("Lua_PeakDuelGuessPanel", Lua_DisplayObject);
function Lua_PeakDuelGuessPanel:ctor(p)
	self:superCall("ctor", p, "PeakDuelGuessPanel_skin");
end

function Lua_PeakDuelGuessPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.left_support_times = 0;
	self.bet_id = 0;
	self.showObject:SetActive(false);

	self:addLuaEvent("PEAK_DUEL_GUESS_INFO", self, self.showGuessInfo);
	self:addLuaEvent("PEAK_DUEL_GUESS_NUM", self, self.updateGuessNum);

	self.leftPanel = Lua_HeroGridViewPanel.new(self.showObject);
	self.leftPanel:setLocation(-200, 305, 0);

	self.rightPanel = Lua_HeroGridViewPanel.new(self.showObject);
	self.rightPanel:setLocation(200, 305, 0);

	self.chatPanel = Lua_CommonChatPanel.new(self.showObject);
	self.chatPanel:setLocation(0, -575, 0);
	self.chatPanel:setChatChannel(Lua_ChatData.CHANNEL_PEAKDUEL);

	Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDGuess();
	Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDGuessResult();

	self.checkFight:addClickFuntion(self, self.onCheckFight);
	self.guess_btn:addClickFuntion(self, self.onCheckRecord);
	self.left_btn:addClickFuntion(self, self.onLeftGuess);
	self.right_btn:addClickFuntion(self, self.onRightGuess);
end

function Lua_PeakDuelGuessPanel:dispose()
	self:endTimer();
	if self.leftPanel ~= nil then
		self.leftPanel:dispose();
		self.leftPanel = nil;
	end
	if self.rightPanel ~= nil then
		self.rightPanel:dispose();
		self.rightPanel = nil;
	end
	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.btnInfo ~= nil then
		self.btnInfo:clear();
		self.btnInfo = nil;
	end
	self:superCall("dispose");
end

function Lua_PeakDuelGuessPanel:showGuessInfo(msg)
	if msg == nil then
		return;
	end

	self.recordId = msg.record_id;

	if msg.is_have_guess == 1 then
		self.showObject:SetActive(true);
		self.noneObject:SetActive(false);

		self.left_role_name = msg.attack_role.show_role.name
		self.left_name.text = "["..msg.attack_role.show_role.server_name.."]"..msg.attack_role.show_role.name;
		self.left_score.text = LanUtil.formateStr("段位积分：{1}", msg.attack_role.score);
		self.left_force.text = LanUtil.formateStr("战力：{1}", msg.attack_role.show_role.force);

		self.right_role_name = msg.defence_role.show_role.name;
		self.right_name.text = "["..msg.defence_role.show_role.server_name.."]"..msg.defence_role.show_role.name;
		self.right_score.text = LanUtil.formateStr("段位积分：{1}", msg.defence_role.score);
		self.right_force.text = LanUtil.formateStr("战力：{1}", msg.defence_role.show_role.force);

		self:updateLineup(msg);
		self:updateStage(msg);
		self:updateGuess(msg);
		self:updateGuessNum(msg);
	else
		self:endTimer();
		self.showObject:SetActive(false);
		self.noneObject:SetActive(true);
	end
end

function Lua_PeakDuelGuessPanel:updateLineup(msg)
	local left_lineup = msg.attack_role.lineup;
	local right_lineup = msg.defence_role.lineup;
	local len = #left_lineup > #right_lineup and #left_lineup or #right_lineup;

	if self.btnInfo == nil then
		self.btnInfo = Array();
	else
		self.btnInfo:clear();
	end

	local lineup1;
	local lineup2;
	for i = 1, len do
		lineup1 = #left_lineup >= i and left_lineup[i] or nil;
		lineup2 = #right_lineup >= i and right_lineup[i] or nil;
		self.btnInfo:add({ textStr = LanUtil.formateStr("第{1}分队", convert_arab_to_chinese(i)), left_lineup = lineup1, right_lineup = lineup2 });
	end

	if len > 1 then
		if self.btnList == nil then
			self.btnList = Lua_ButtonList.new(self.showObject, Lua_AxisDefine.Horizontal);
			self.btnList:setLocation(0, 40, 0);
			self.btnList:setButtonItem(184, 62);
			self.btnList:setClickCallBack(self, self.onButtonClick);
			self.btnList:setData(self.btnInfo);
			self.btnList:setSelected(1);
		end
		self.btnList:setEnable(true);
		self.prompt.text = "";
	else
		if self.btnList ~= nil then
			self.btnList:setEnable(false);
		end
		self:onButtonClick(1);
		self.prompt.text = "本次比赛为单队伍比赛";
	end
end

function Lua_PeakDuelGuessPanel:onButtonClick(index)
	local data = self.btnInfo[index];
	if data == nil then
		self.leftPanel:setDataByProto(nil);
		self.rightPanel:setDataByProto(nil);
	else
		self.leftPanel:setDataByProto(data.left_lineup.hero_list);
		self.rightPanel:setDataByProto(data.right_lineup.hero_list);
	end
end

function Lua_PeakDuelGuessPanel:updateStage(msg)
	self.stageType = 0;
	self.intervalNum = 0;
	self.leftTime = 0;

	local serverTime = DataCenter.roleData.serverTime;
	if serverTime < tonumber(msg.guess_stage_info.interaction_end_tick) then -- 互动阶段
		self.stageType = 1;
		self.left_result:setEnable(false);
		self.right_result:setEnable(false);
		self.checkFight:setEnable(false);
		self.show_stage.text = "互动阶段";
		self.endTime = tonumber(msg.guess_stage_info.interaction_end_tick);
		self:startTimer();
		self:onTimer();
	elseif serverTime < tonumber(msg.guess_stage_info.match_end_tick) then -- 比赛阶段
		self.left_result:setEnable(false);
		self.right_result:setEnable(false);
		self.checkFight:setEnable(true);
		self.show_stage.text = "比赛阶段";
		self.endTime = tonumber(msg.guess_stage_info.match_end_tick);
		self:startTimer();
		self:onTimer();
	elseif serverTime < tonumber(msg.guess_stage_info.next_start_tick) then -- 结算阶段
		self.left_result:setEnable(true);
		self.right_result:setEnable(true);
		if msg.win_id == 1 then
			self.left_result:setAltas("common_altas_3", "ui_zd_icon_011");
			self.right_result:setAltas("common_altas_3", "ui_zd_icon_012");
		else
			self.left_result:setAltas("common_altas_3", "ui_zd_icon_012");
			self.right_result:setAltas("common_altas_3", "ui_zd_icon_011");
		end
		self.checkFight:setEnable(true);
		self.show_stage.text = "结算阶段";
		self.endTime = tonumber(msg.guess_stage_info.next_start_tick);
		self:startTimer();
		self:onTimer();
	else
		self:endTimer();
		self.left_result:setEnable(false);
		self.right_result:setEnable(false);
		self.checkFight:setEnable(false);
		self.show_stage.text = "";
		self.show_time.text = "";
	end
end

function Lua_PeakDuelGuessPanel:startTimer()
	if self.bTiming ~= true then
		self.bTiming = true;
		self:addTimer("Lua_PeakDuelGuessPanel", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_PeakDuelGuessPanel:endTimer()
	if self.bTiming == true then
		self.bTiming = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_PeakDuelGuessPanel:onTimer()
	if self.stageType == 1 then
		self.intervalNum = self.intervalNum + 1;
		if self.intervalNum > 4 then
			Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDGuessNum();
			self.intervalNum = 0;
		end
	end

	self.leftTime = self.endTime - DataCenter.roleData.serverTime;
	if self.leftTime <= 0 then
		self:endTimer();
		Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDGuess();
		if self.stageType == 1 then
			self:onCheckFight();
			Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDGuessResult();
		end
		self.show_time.text = "";
	else
		self.show_time.text = Lua_TimeTransform.transSeconds6(self.leftTime);
	end
end

function Lua_PeakDuelGuessPanel:updateGuess(msg)
	self.left_support_times = msg.left_support_times;
	self.bet_id = msg.bet_id;

	local total_times = DataCenter.peakDuelUtil.daily_guess_times;
	local guess_times = total_times - msg.left_support_times;

	local tab;
	if msg.left_support_times <= 0 then
		tab = { "<color=#", Lua_ColorDefine.RED_STR, ">", guess_times, "</color>/", total_times };
	else
		tab = { "<color=#", Lua_ColorDefine.GREEN_STR, ">", guess_times, "</color>/", total_times };
	end
	self.guess_txt.text = LanUtil.formateStr("今日竞猜次数：{1}", table.concat( tab, "" ));

	if msg.bet_id == 1 then
		self.left_self:setEnable(true);
		self.right_self:setEnable(false);
		self.left_txt.text = "已支持";
		self.right_txt.text = "支持";
	elseif msg.bet_id == 2 then
		self.left_self:setEnable(false);
		self.right_self:setEnable(true);
		self.left_txt.text = "支持";
		self.right_txt.text = "已支持";
	else
		self.left_self:setEnable(false);
		self.right_self:setEnable(false);
		self.left_txt.text = "支持";
		self.right_txt.text = "支持";
	end
end

function Lua_PeakDuelGuessPanel:updateGuessNum(msg)
	self.left_guess.text = LanUtil.formateStr("支持人数：{1}", tostring(msg.attack_role_num));
	self.right_guess.text = LanUtil.formateStr("支持人数：{1}", tostring(msg.defence_role_num));

	local max_value = msg.attack_role_num + msg.defence_role_num;
	local value = msg.attack_role_num;
	if max_value <= 0 then
		max_value = 2;
		value = 1;
	end
	local show_value = Mathf.Floor(value / max_value) * 100;
	
	self.guessBar:setMaxValue(max_value);
	self.guessBar:setValue(show_value);
	self.guessBar:setText(show_value.."%");
end

function Lua_PeakDuelGuessPanel:onCheckFight(go)
	if self.recordId == nil then
		return;
	end
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(self.recordId);
end

function Lua_PeakDuelGuessPanel:onCheckRecord(go)
	Lua_WindowUtil.openWin("Lua_PeakDuelGuessRecordWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_PeakDuelGuessPanel:onLeftGuess(go)
	if self.left_support_times <= 0 then
		OperateAlert.show("今日已达支持上限");
		return;
	end

	if self.bet_id > 0 then
		OperateAlert.show("你已支持过选手");
		return;
	end

	Lua_WindowUtil.openWin("Lua_PeakDuelGuessSelectWindow", Lua_WinParam.ACTION_OPEN, { bet_id = 1, name = self.left_role_name });
end

function Lua_PeakDuelGuessPanel:onRightGuess(go)
	if self.left_support_times <= 0 then
		OperateAlert.show("今日已达支持上限");
		return;
	end

	if self.bet_id > 0 then
		OperateAlert.show("你已支持过选手");
		return;
	end

	Lua_WindowUtil.openWin("Lua_PeakDuelGuessSelectWindow", Lua_WinParam.ACTION_OPEN, { bet_id = 2, name = self.right_role_name });
end