Lua_PeakDuelRankPanel = class("Lua_PeakDuelRankPanel", Lua_DisplayObject);
function Lua_PeakDuelRankPanel:ctor(p)
	self:superCall("ctor", p, "PeakDuelRankPanel_skin");
end

function Lua_PeakDuelRankPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.maxTimesIdx = 1;
	self.selectedTimesIdx = self.maxTimesIdx;

	self:addLuaEvent("PEAK_DUEL_RANK_SEASON", self, self.onSeasonInfo);
	self:addLuaEvent("PEAK_DUEL_RANK_INFO", self, self.onRankInfo);
	self:addLuaEvent("PEAK_DUEL_DIVISION_SELECT", self, self.onDivisionSelect);
	self:addLuaEvent("PEAK_DUEL_RANK_LIKE", self, self.onLike);
	self:addLuaEvent("PEAK_DUEL_RANK_UPDATE", self, self.updateRankInfo);

	self.btnInfo = Array();
	self.btnInfo:add({ textStr = "赛区" });
	self.btnInfo:add({ textStr = "本服" });

	self.btnList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
	self.btnList:setRectAnchor(7);
	self.btnList:setLocation(0, 135, 0);
	self.btnList:setButtonItem(184, 62);
	self.btnList:setClickCallBack(self, self.onButtonClick);
	self.btnList:setData(self.btnInfo);
	self.btnList:setSelected(1);

	self.rankList = Lua_DragList.new(self.content, 700, 430, Lua_AxisDefine.Vertical);
	self.rankList:setRectAnchor(7);
	self.rankList:setLocation(0, 555, 0);
	self.rankList:setListCell(Lua_PeakDuelRankItem, 700, 150, 1);

	self.rankItem = Lua_PeakDuelRankItem.new(self.content);
	self.rankItem:setRectAnchor(7);
	self.rankItem:setLocation(0, 255, 0);

	self.btnLeft:addClickFuntion(self, self.onLeftClick);
	self.btnRight:addClickFuntion(self, self.onRightClick);
	self.checkDivision:addClickFuntion(self, self.onCheckDivision);
end

function Lua_PeakDuelRankPanel:dispose()
	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.btnInfo ~= nil then
		self.btnInfo:clear();
		self.btnInfo = nil;
	end
	if self.modelArr ~= nil then
		self.modelArr:dispose();
		self.modelArr:clear();
		self.modelArr = nil;
	end
	if self.rankList ~= nil then
		self.rankList:dispose();
		self.rankList = nil;
	end
	if self.rankItem ~= nil then
		self.rankItem:dispose();
		self.rankItem = nil;
	end
	self:superCall("dispose");
end

function Lua_PeakDuelRankPanel:onButtonClick(index)
	self.selectedIdx = index;
	self.btnLeft:setEnable(index == 1);
	self.btnRight:setEnable(index == 1);
	self.checkDivision:setEnable(index == 1);

	if index == 1 then
		Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sSeason(DataCenter.peakDuelData.region_id);
	else
		Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDRank(0, DataCenter.peakDuelData.times);
		self.region_name = DataCenter.peakDuelData.region_name;
	end
end

function Lua_PeakDuelRankPanel:onSeasonInfo(msg)
	if msg == nil then
		return;
	end

	self.region_id = tonumber(msg.region_id);
	self.region_name = msg.region_name;
	self.times_list = msg.times_list;

	self.maxTimesIdx = #self.times_list;
	self.selectedTimesIdx = self.maxTimesIdx;

	self.times = self.times_list[self.selectedTimesIdx];
	self.season_text.text = LanUtil.formateStr("S{1}赛季（{2}）", tostring(self.times), self.region_name);
	Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDRank(self.region_id, self.times);
end

function Lua_PeakDuelRankPanel:onRankInfo(msg)
	if msg == nil then
		return;
	end

	local total_like_times = DataCenter.peakDuelUtil.daily_praise_num;
	local like_times = total_like_times - DataCenter.peakDuelData.left_praise_times;
	self.likeText.text = LanUtil.formateStr("今日点赞次数{1}/{2}", tostring(like_times), tostring(total_like_times));

	self:updateRankInfo();
end

function Lua_PeakDuelRankPanel:updateRankInfo()
	self:showModelItem();
	self.rankList:setArrayData(DataCenter.peakDuelData.rankArr);
	self.rankItem:setData(DataCenter.peakDuelData.myRankVo);
end

function Lua_PeakDuelRankPanel:showModelItem()
	if self.modelArr == nil then
		self.modelArr = Array();
	end

	local pos = {{0, 350}, {-225, 320}, {225, 290}};
	local item;
	local vo;
	for i = 1, 3 do
		item = self.modelArr[i];
		if item == nil then
			item = Lua_PeakDuelModelItem.new(self.content);
			self.modelArr:add(item);
		end
		item:setLocation(pos[i][1], pos[i][2], 0);
		item:setRank(i);
		vo = DataCenter.peakDuelData:getRankInfo(i);
		item:setData(vo);
	end
end

function Lua_PeakDuelRankPanel:onDivisionSelect(id)
	local times = self.times_list[self.selectedTimesIdx];
	Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDRank(self.region_id, times);
end

function Lua_PeakDuelRankPanel:onLike(data)
	if self.selectedIdx == 1 then
		Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDLike(data.role_id, self.region_id, self.times, data.score);
	else
		Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDLike(data.role_id, 0, self.times, data.score);
	end
end

function Lua_PeakDuelRankPanel:onLeftClick(go)
	if self.selectedTimesIdx <= 1 then
		OperateAlert.show("暂无其他赛季");
		return;
	end
	self.selectedTimesIdx = self.selectedTimesIdx - 1;

	self.times = self.times_list[self.selectedTimesIdx];
	self.season_text.text = LanUtil.formateStr("S{1}赛季（{2}）", tostring(self.times), self.region_name);
	Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDRank(self.region_id, self.times);
end

function Lua_PeakDuelRankPanel:onRightClick(go)
	if self.selectedTimesIdx >= self.maxTimesIdx then
		OperateAlert.show("暂无其他赛季");
		return;
	end
	self.selectedTimesIdx = self.selectedTimesIdx + 1;

	self.times = self.times_list[self.selectedTimesIdx];
	self.season_text.text = LanUtil.formateStr("S{1}赛季（{2}）", tostring(self.times), self.region_name);
	Lua_ProxyManager.getProxy("Lua_PeakDuelProxy"):sPDRank(self.region_id, self.times);
end

function Lua_PeakDuelRankPanel:onCheckDivision(go)
	Lua_WindowUtil.openWin("Lua_PeakDuelDivisionWindow", Lua_WinParam.ACTION_OPEN);
end




















Lua_PeakDuelRankItem = class("Lua_PeakDuelRankItem", Lua_ListCell);
function Lua_PeakDuelRankItem:ctor(p)
	self:superCall("ctor", p, "PeakDuelRankItem_skin");
end

function Lua_PeakDuelRankItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);
    self.avatarItem:setLocation(-160, 0, 0);

    self.btnLike:addClickFuntion(self, self.onLikeClick);
end

function Lua_PeakDuelRankItem:dispose()
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_PeakDuelRankItem:setData(data)
	if type(data) == "number" then
		self.data = DataCenter.peakDuelData:getRankInfo(data);
	else
		self.data = data;
	end

	if self.data == nil then
		return;
	end

	if self.data.rank <= 0 then
		self.rankText.text = "暂未上榜";
	else
		self.rankText.text = self.data.rank;
	end

    self.avatarItem:setRoleDressUp(self.data.show_role.dress_info);
    self.avatarItem:setRoleVip(self.data.show_role.vip);
    self.avatarItem:setRoleLevel(self.data.show_role.level);

    self.nameText.text = self.data.show_role.name;
	if tonumber(self.data.show_role.league_id) > 0 then
		self.allianceText.text = self.data.show_role.league_name;
	else
		self.allianceText:setLangValue(20);
	end

    local configData = DataCenter.peakDuelUtil:getSegmentInfoByid(self.data.segment_lvl);
    self.segmentText.text = configData.name;
    self.scoreText.text = self.data.score;
    self.likeText.text = self.data.praise_num;

	if self.data.is_praised == 1 then
		self.btnLike:setAltas("common_altas_2", "ui_common_button_037_n");
		self.btnLike.mouseEnable = false;
	else
		self.btnLike:setAltas("common_altas_2", "ui_common_button_038_n");
		self.btnLike.mouseEnable = true;
	end
end

function Lua_PeakDuelRankItem:onLikeClick(go)
	if self.data == nil then
		return;
	end

	if DataCenter.roleData:isMyself(self.data.role_id) then
		OperateAlert.show("不可对自己点赞");
		return;
	end

	if DataCenter.peakDuelData.left_praise_times <= 0 then
		OperateAlert.show("今日点赞次数已用完");
		return;
	end
	Lua_MsgUtil.callFunc("PEAK_DUEL_RANK_LIKE", self.data);
end